diff src/term.c @ 83341:76e51706154e

Rename term_init to init_tty. * src/term.c (term_init): Rename to init_tty. * src/dispextern.h (term_init): Rename to init_tty. * src/dispnew.c (init_display): Update. * src/frame.c (Fmake_terminal_frame): Update. * src/term.c (tty_setup_colors): Update comment. git-archimport-id: lorentey@elte.hu--2004/emacs--multi-tty--0--patch-381
author Karoly Lorentey <lorentey@elte.hu>
date Sun, 10 Jul 2005 22:25:28 +0000
parents 5f293f92f85e
children 9216636c02fc
line wrap: on
line diff
--- a/src/term.c	Sun Jul 10 22:18:46 2005 +0000
+++ b/src/term.c	Sun Jul 10 22:25:28 2005 +0000
@@ -2023,7 +2023,7 @@
 /* Setup one of the standard tty color schemes according to MODE.
    MODE's value is generally the number of colors which we want to
    support; zero means set up for the default capabilities, the ones
-   we saw at term_init time; -1 means turn off color support.  */
+   we saw at init_tty time; -1 means turn off color support.  */
 void
 tty_setup_colors (struct tty_display_info *tty, int mode)
 {
@@ -2358,7 +2358,7 @@
    If MUST_SUCCEED is true, then all errors are fatal. */
 
 struct display *
-term_init (char *name, char *terminal_type, int must_succeed)
+init_tty (char *name, char *terminal_type, int must_succeed)
 {
   char *area;
   char **address = &area;
@@ -2376,7 +2376,7 @@
 
   /* If we already have an active display on the given device, use that.
      If all displays are suspended, create a new one instead.  */
   /* XXX Perhaps this should be made explicit by having term_init
      always create a new display and separating display and frame
      creation on Lisp level.  */
   display = get_named_tty_display (name);
@@ -2931,7 +2931,7 @@
 #endif /* not WINDOWSNT */
 }
 
 /* Auxiliary error-handling function for term_init.
    Free BUFFER and delete DISPLAY, then call error or fatal
    with str1 or str2, respectively, according to MUST_SUCCEED.  */
@@ -2376,7 +2376,7 @@
   /* If we already have an active display on the given device, use that.
      If all displays are suspended, create a new one instead.  */
-  /* XXX Perhaps this should be made explicit by having term_init
+  /* XXX Perhaps this should be made explicit by having init_tty
      always create a new display and separating display and frame
      creation on Lisp level.  */
@@ -2931,7 +2931,7 @@
 }
 
-/* Auxiliary error-handling function for term_init.
+/* Auxiliary error-handling function for init_tty.
    Free BUFFER and delete DISPLAY, then call error or fatal
    with str1 or str2, respectively, according to MUST_SUCCEED.  */